flask-peewee — flask-peewee v0.1.0 documentation

### Navigation

- index
- next |
- flask-peewee v0.1.0 documentation »

# flask-peewee

Welcome to the flask-peewee documentation!

provides a layer of integration between the flask web framework and the peewee orm.

Contents:

- Installing
  - Using git
- Getting Started
  - Creating a flask app
  - Creating a simple model
  - Setting up a simple base template
  - Adding users to the site
  - Managing content using the admin area
  - Exposing content using a REST API
- Database Wrapper
- Admin Interface
  - Getting started
  - Components of the Admin
- Authentication
  - Getting started
  - Marking areas of the site as login required
  - Retrieving the current user
  - Accessing the user in the templates
  - Using a custom “User” model
  - Components of the auth system
- REST Api
  - Getting started with the API
  - Components of the rest module
- Utilities

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- flask-peewee v0.1.0 documentation »